Publications Using CLEASE
==========================

If you found CLEASE to be a useful tool and have used it in a publication, we
invite you to add your work to the list below. This makes it easy for other
CLEASE users to see your work as well as showing examples of research topics
where cluster expansion techniques are useful. The list is sorted by
publication date, where the latest publications appear on top. In order to
add a contribution to the list, you can open a merge request to the `CLEASE
repository <https://gitlab.com/computationalmaterials/clease>`_.

* Chable, J., Baur, C., Chang, J.H., Wenzel, S., García-Lastra, J.M. and Vegge, T., 2019.
    `From Trigonal to Cubic LiVO2: A High-Energy Phase Transition Towards Disordered Rock Salt Materials. <https://doi.org/10.1021/acs.jpcc.9b11235>`_
    *The Journal of Physical Chemistry C.*

* Tranås, R.A., 2019.
    `Atomistic simulations of thermodynamics and dissolution of iron-silicon phases in iron encasements <http://hdl.handle.net/11250/2625264>`_
    *(Master's thesis, NTNU).*

* Chang, J.H., Kleiven, D., Melander, M., Akola, J., Garcia-Lastra, J.M. and Vegge, T., 2019.
    `CLEASE: A versatile and user-friendly implementation of Cluster Expansion method.  <https://doi.org/10.1088/1361-648X/ab1bbc>`_
    *Journal of Physics: Condensed Matter*, 31(32), p.325901.

* Kleiven, D., Ødegård, O.L., Laasonen, K. and Akola, J., 2019.
    `Atomistic simulations of early stage clusters in AlMg alloys. <https://doi.org/10.1016/j.actamat.2018.12.050>`_
    *Acta Materialia*, 166, pp.484-492.
